<?php
use Elementor\Group_Control_Image_Size;
/**
 * Tiny Portfolio Grid Template
 *
 * @package Tiny Portfolio
 * @since   1.0.0
 */

$columns_class = 'columns-' . $tp_data->columns;

/* Get data */
$portfolio_items = $tp_data->items;
$items_per_page = $tp_data->items_per_page;
$enable_infinite_scroll = $tp_data->enable_infinite_scroll;
$load_more_button = $tp_data->load_more_button;
$load_more_button_text = $tp_data->load_more_button_text;

/* Pagination */
$count = count( $portfolio_items );
$current_page = isset( $_GET['tp_page'] ) ? $_GET['tp_page'] : 1;
$per_page = $items_per_page;
$total_pages = ceil( $count / $per_page );
$items = array_slice( $portfolio_items, ( $current_page-1 ) * $per_page, $per_page );
?>
<div class="tp-portfolio <?php echo $columns_class; ?>" id="tp-portfolio-<?php echo $tp_data->id; ?>" data-infinite="<?php echo $enable_infinite_scroll;?>" data-load-more-button="<?php echo $load_more_button; ?>">

	<?php
	    $i = 1;
		foreach( $items as $item ):

			$images = array();
			foreach( $item['images'] as $image ){
				$images[] = $image['url'];
			}
			$data_images = implode('|', $images);
            $item_data  = 'data-title="' . esc_html( $item['title'] ) . '"';
			$item_data .= ' data-services="' . esc_html( $item['services'] ) . '"';
			$item_data .= ' data-client="' . esc_html( $item['client'] ) . '"';
			$item_data .= ' data-date="' . esc_html( $item['date'] ) . '"';
			$item_data .= ' data-content="' . esc_attr( $item['content'] ) . '"';
			$item_data .= ' data-type="' . esc_html( $item['type'] ) . '"';

			if( $item['type'] == 'audio' ) {
				$item_data .= ' data-audio="' . $item['audio']['url'] . '"';
			}elseif( $item['type'] == 'video' ){
				if( $item['video_type'] === 'youtube' ) {
					$item_data .= ' data-video="' . $item['youtube']['url'] . '"';
				}elseif( $item['video_type'] === 'vimeo' ){
					$item_data .= ' data-video="' . $item['vimeo']['url'] . '"';
				}
			}elseif( $item['type'] == 'image' ){
				$item_data .= ' data-images="' . $data_images . '"';
			}

			$last = $i % $tp_data->columns == 0 ? 'last' : '';
			$featured_image = wp_get_attachment_image_src($item['featured_image']['id'], 'large' );
	?>
		<div class="grid-item <?php echo $last; ?>" <?php echo $item_data; ?>>
			<div class="grid-thumbnail" <?php echo 'style="background-image:url(' . $featured_image[0] . ');"'; ?>>
				<?php if( $tp_data->title_position == 'inside' ): ?>
					<div class="grid-content">
						<h4 class="grid-title"><?php echo esc_html( $item['title']); ?></h4>
						<?php if( $item['show_excerpt'] ) : ?>
						<div class="excerpt"><?php echo wp_trim_words( wp_kses_post( $item['content'] ), 50 ); ?></div>
						<?php endif; ?>
					</div>
					<div class="grid-overlay"></div>
				<?php endif;?>
			</div>
			<?php if( $tp_data->title_position == 'outside' ): ?>
				<h4 class="grid-title"><?php echo esc_html( $item['title']); ?></h4>
				<?php if( $item['show_excerpt'] ) : ?>
				<div class="excerpt"><?php echo wp_trim_words( wp_kses_post( $item['content'] ), 50 ); ?></div>
				<?php endif; ?>
			<?php endif;?>
		</div>
	<?php $i++; endforeach; ?>

	<?php
	    // Pagination
		if( $enable_infinite_scroll == '1' ) {
			$pagination = '<div class="tp-page-links">';

	        if( ! isset($_GET['tp_page']) || $_GET['tp_page'] <= 1 ) {
	            $pagination .= '';
	        }else{
	            $pagination .= '<a href="?tp_page=' . ( $current_page-1 ) . '" class="tp-previous-link">Previous</a>';
	        }

	        if( isset( $_GET['tp_page'] ) && $_GET['tp_page'] >= $total_pages ) {
	            $pagination .= '';
	        }else{
	            $pagination .= '<a href="?tp_page=' . ( $current_page+1 ) .'" class="tp-next-link" id="tp-next-link-'.$tp_data->id.'">Next</a>';
	        }

	        $pagination .= '</div>';

	        echo $pagination;
    	}
   ?>

   	<div class="tp-load-status">
          <div class="infinite-scroll-request">
				<div class="tp-loader"><div></div><div></div><div></div></div>
          </div>
    </div>

    <?php
	    if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
	        echo '<script>window.TP.singlePortfolio();</script>';
	    }
    ?>

</div>

<?php if( $load_more_button ): ?>
<div class="tp-more-button"><a href="javascript:;" class="view-more-button"><?php echo esc_html( $load_more_button_text );?></a></div>
<?php endif; ?>
